@@ -25,7 +25,7 @@ public:
     QStringList m_collectionHeaders;
     QStringList m_itemHeaders;
 
-    Q_REQUIRED_RESULT virtual QVariant entityData(const Item &item, int column, int role) const = 0;
+    [[nodiscard]] virtual QVariant entityData(const Item &item, int column, int role) const = 0;
 };
 
 class GenericState : public AkonadiBrowserModel::State
@@ -41,7 +41,7 @@ public:
 
     enum Columns { IdColumn = 0, RemoteIdColumn = 1, GIDColumn = 2, MimeTypeColumn = 3 };
 
-    Q_REQUIRED_RESULT QVariant entityData(const Item &item, int column, int role) const override
+    [[nodiscard]] QVariant entityData(const Item &item, int column, int role) const override
     {
         if (Qt::DisplayRole != role) {
             return {};
@@ -72,7 +72,7 @@ public:
 
     ~MailState() override = default;
 
-    Q_REQUIRED_RESULT QVariant entityData(const Item &item, int column, int role) const override
+    [[nodiscard]] QVariant entityData(const Item &item, int column, int role) const override
     {
         if (Qt::DisplayRole != role) {
             return {};
@@ -120,7 +120,7 @@ public:
 
     ~ContactsState() override = default;
 
-    Q_REQUIRED_RESULT QVariant entityData(const Item &item, int column, int role) const override
+    [[nodiscard]] QVariant entityData(const Item &item, int column, int role) const override
     {
         if (Qt::DisplayRole != role) {
             return {};
@@ -167,7 +167,7 @@ public:
 
     ~CalendarState() override = default;
 
-    Q_REQUIRED_RESULT QVariant entityData(const Item &item, int column, int role) const override
+    [[nodiscard]] QVariant entityData(const Item &item, int column, int role) const override
     {
         if (Qt::DisplayRole != role) {
             return {};
@@ -367,3 +367,5 @@ bool AkonadiBrowserSortModel::lessThan(const QModelIndex &left, const QModelInde
 
     return QSortFilterProxyModel::lessThan(left, right);
 }
+
+#include "moc_akonadibrowsermodel.cpp"
