@@ -289,7 +289,7 @@ void TagPropertiesDialog::slotAccept()
     }
     if (queryOK && mTag.isValid() && !mChangedRIDs.isEmpty()) {
         QMap<QString, qint64> resourceNameToIdMap;
-        QVector<qint64> existingResourceRecords;
+        QList<qint64> existingResourceRecords;
         {
             QSqlQuery query(DbAccess::database());
             QString queryStr = QStringLiteral("SELECT id, name FROM ResourceTable WHERE ");
@@ -369,3 +369,5 @@ void TagPropertiesDialog::slotAccept()
 
     QDialog::accept();
 }
+
+#include "moc_tagpropertiesdialog.cpp"
